@@ -9,12 +9,12 @@ use Carp qw(croak);
 use Fcntl qw(LOCK_EX LOCK_NB);
 use English qw(-no_match_vars);
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 has lock_file => (get => '+', set => '-');
 has is_locked => (get => '+', set => '-');
 
-has fh => (set => '-');
+has fh => (get => '-', set => '-');
 
 sub new {
     my ($class, %param) = @ARG;
@@ -42,7 +42,7 @@ sub lock {
     # Re-locking changes nothing
     return $self if $self->is_locked;
 
-    my $fh = IO::File->new($self->lock_file, O_WRONLY|O_CREAT)
+    my $fh = IO::File->new($self->lock_file, O_RDWR|O_CREAT)
         or croak(sprintf qq{Can't open "%s": %s\n}, $self->lock_file, $OS_ERROR);
 
     flock $fh, LOCK_EX|LOCK_NB
@@ -66,7 +66,7 @@ sub try_lock {
     # Re-locking changes nothing
     return $self if $self->is_locked;
 
-    my $fh = IO::File->new($self->lock_file, O_WRONLY|O_CREAT);
+    my $fh = IO::File->new($self->lock_file, O_RDWR|O_CREAT);
 
     if ($fh and flock $fh, LOCK_EX|LOCK_NB) {
         truncate $fh, 0
@@ -121,7 +121,7 @@ JIP::LockFile - application lock/mutex based on files
 
 =head1 VERSION
 
-Version 0.02
+Version 0.05
 
 =head1 SYNOPSIS
 
